@@ -24,7 +24,6 @@ import json
 
 import nbformat
 import json
-import cortx_constants
 
 Config = namedtuple('Config', [
  'prefix', 'region', 'bucket_name', 'host_name', 'cortx_authenticator',
@@ -34,6 +33,7 @@ CredentialConfig = namedtuple('CredentialConfig', [
     'access_key_id', 'secret_access_key'
 ])
 
+cortx_constants = {'NB_TYPE' :'.ipynb', 'UNTITLED_FILE' :'Untitled', 'FOLDER_SEPERATOR' : '/', 'UNTITLED_NB' :'Untitled', 'UNTITLED_FOLDER' : 'Untitled Folder','CHECKPOINT_NAME' : '.checkpoints'}
 
 class ExpiringDict:
 
@@ -217,7 +217,7 @@ def _final_path_component(key_or_path):
 # The sort keys keep the UI as reasonable as possible with long running
 # actions acting on multiple objects, including if things fail in the middle
 def _copy_sort_key(key):
-    return (key.count('/'), 0 if key.endswith(constants.FOLDER_SEPERATOR) else 1)
+    return (key.count('/'), 0 if key.endswith(cortx_constants['FOLDER_SEPERATOR']) else 1)
 
 
 def _delete_sort_key(key):
@@ -229,7 +229,7 @@ def _delete_sort_key(key):
 @gen.coroutine
 def _type_from_path(context, path):
     type = \
-        'notebook' if path.endswith(constants.NB_TYPE) else \
+        'notebook' if path.endswith(cortx_constants["NB_TYPE"]) else \
         'directory' if _is_root(path) or (yield _dir_exists(context, path)) else \
         'file'
     return type
@@ -246,14 +246,14 @@ def _format_from_type_and_path(context, type, path):
 
 def _type_from_path_not_directory(path):
     type = \
-        'notebook' if path.endswith(constants.NB_TYPE) else \
+        'notebook' if path.endswith(cortx_constants["NB_TYPE"]) else \
         'file'
     return type
 
 
 @gen.coroutine
 def _dir_exists(context, path):
-    return True if _is_root(path) else (yield _file_exists(context, path + constants.FOLDER_SEPERATOR))
+    return True if _is_root(path) else (yield _file_exists(context, path + cortx_constants["FOLDER_SEPERATOR"]))
 
 
 def _is_root(path):
@@ -370,7 +370,7 @@ def _get_directory(context, path, content):
                 'last_modified': last_modified,
             }
             for (key, last_modified) in keys
-            if not key.endswith(constants.FOLDER_SEPERATOR)
+            if not key.endswith(cortx_constants["FOLDER_SEPERATOR"])
         ]) if content else None
     }
 
@@ -405,7 +405,7 @@ def _save_file_text(context, chunk, content, path):
 
 @gen.coroutine
 def _save_directory(context, chunk, content, path):
-    return (yield _save_any(context, chunk, b'', path + constants.FOLDER_SEPERATOR, 'directory', None))
+    return (yield _save_any(context, chunk, b'', path + cortx_constants["FOLDER_SEPERATOR"], 'directory', None))
 
 
 @gen.coroutine
@@ -472,7 +472,7 @@ def _increment_filename(context, filename, path='', insert=''):
 
 
 def _checkpoint_path(path, checkpoint_id):
-    return path + '/' + constants.CHECKPOINT_NAME + '/' + checkpoint_id
+    return path + '/' + cortx_constants["CHECKPOINT_NAME"] + '/' + checkpoint_id
 
 
 @gen.coroutine
@@ -515,11 +515,11 @@ def _delete_checkpoint(context, checkpoint_id, path):
 
 @gen.coroutine
 def _list_checkpoints(context, path):
-    key_prefix = _key(context, path + '/' + constants.CHECKPOINT_NAME + '/')
+    key_prefix = _key(context, path + '/' + cortx_constants["CHECKPOINT_NAME"] + '/')
     keys, _ = yield _list_immediate_child_keys_and_directories(context, key_prefix)
     return [
         {
-            'id': key[(key.rfind('/' + constants.CHECKPOINT_NAME + '/') + len('/' + constants.CHECKPOINT_NAME + '/')):],
+            'id': key[(key.rfind('/' + cortx_constants["CHECKPOINT_NAME"] + '/') + len('/' + cortx_constants["CHECKPOINT_NAME"] + '/')):],
             'last_modified': last_modified,
         }
         for key, last_modified in keys
@@ -606,9 +606,9 @@ def _new_untitled(context, path, type, ext):
         'file'
 
     untitled = \
-        constants.UNTITLED_FOLDER if model_type == 'directory' else \
-        constants.UNTITLED_NB if model_type == 'notebook' else \
-        constants.constants.constants.UNTITLED_FILE
+        cortx_constants["UNTITLED_FOLDER"] if model_type == 'directory' else \
+        cortx_constants["UNTITLED_NB"] if model_type == 'notebook' else \
+        cortx_constants["UNTITLED_FILE"]
     insert = \
         ' ' if model_type == 'directory' else \
         ''
